Index: /main/waeup.uniben/trunk/src/waeup/uniben/applicants/browser_templates/payment_view.pt
===================================================================
--- /main/waeup.uniben/trunk/src/waeup/uniben/applicants/browser_templates/payment_view.pt	(revision 8440)
+++ /main/waeup.uniben/trunk/src/waeup/uniben/applicants/browser_templates/payment_view.pt	(revision 8441)
@@ -1,3 +1,3 @@
-<table class="form-table" i18n:domain="waeup.uniben"
+<table class="form-table" i18n:domain="waeup.custom"
   tal:define="files provider:files">
   <tbody>
Index: /main/waeup.uniben/trunk/src/waeup/uniben/applicants/export.py
===================================================================
--- /main/waeup.uniben/trunk/src/waeup/uniben/applicants/export.py	(revision 8440)
+++ /main/waeup.uniben/trunk/src/waeup/uniben/applicants/export.py	(revision 8441)
@@ -24,5 +24,5 @@
 
 class CustomApplicantsExporter(ApplicantsExporter):
-    """Exporter for Uniben Applicants.
+    """Exporter for Custom Applicants.
     """
 
Index: /main/waeup.uniben/trunk/src/waeup/uniben/browser/resources.py
===================================================================
--- /main/waeup.uniben/trunk/src/waeup/uniben/browser/resources.py	(revision 8440)
+++ /main/waeup.uniben/trunk/src/waeup/uniben/browser/resources.py	(revision 8441)
@@ -21,9 +21,9 @@
     )
 
-#: All local resources are registered under the name ``waeup_custom``.
+#: All local resources are registered under the name ``waeup_uniben``.
 waeup_uniben = Library('waeup_uniben', 'static')
 
-custom_theme_1 = ResourceInclusion(
-    waeup_uniben, 'custom_theme_1.css',
+custom_theme = ResourceInclusion(
+    waeup_uniben, 'custom_theme.css',
     depends = [waeup_base_css])
 
Index: /main/waeup.uniben/trunk/src/waeup/uniben/browser/static/custom_theme.css
===================================================================
--- /main/waeup.uniben/trunk/src/waeup/uniben/browser/static/custom_theme.css	(revision 8441)
+++ /main/waeup.uniben/trunk/src/waeup/uniben/browser/static/custom_theme.css	(revision 8441)
@@ -0,0 +1,72 @@
+.topbar-inner, .topbar .fill {
+  background-color: #8A0474;
+  background-image: -moz-linear-gradient(center top , #4e0242, #8A0474);
+  background-image: -khtml-gradient(linear, left top, left bottom, from(#4e0242), to(#8A0474));
+  background-image: -moz-linear-gradient(top, #4e0242, #8A0474);
+  background-image: -ms-linear-gradient(top, #4e0242, #8A0474);
+  background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #4e0242), color-stop(100%, #8A0474));
+  background-image: -webkit-linear-gradient(top, #4e0242, #8A0474);
+  background-image: -o-linear-gradient(top, #4e0242, #8A0474);
+  background-image: linear-gradient(top, #4e0242, #8A0474);
+  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#4e0242', endColorstr='#8A0474', GradientType=0);
+}
+
+.topbar div > ul .active > a, .nav .active > a {
+  background-color: #8A0474;
+}
+
+.topbar h3 a:hover, .topbar .brand:hover, .topbar ul .active > a {
+  background-color: #8A0474;
+}
+
+.topbar div > ul a:hover, .nav a:hover {
+  background-color: #8A0474;
+}
+
+
+.topbar div > ul .menu-dropdown,
+.nav .menu-dropdown,
+.topbar div > ul .dropdown-menu,
+.nav .dropdown-menu {
+  background-color: #8A0474;
+}
+
+.topbar div > ul a.menu:hover,
+.nav a.menu:hover,
+.topbar div > ul li.open .menu,
+.nav li.open .menu,
+.topbar div > ul .dropdown-toggle:hover,
+.nav .dropdown-toggle:hover,
+.topbar div > ul .dropdown.open .dropdown-toggle,
+.nav .dropdown.open .dropdown-toggle {
+  background: #8A0474;
+}
+
+body {
+  background-color: #f3eff2;
+}
+
+.topbar div > ul .menu-dropdown li a:hover,
+.nav .menu-dropdown li a:hover,
+.topbar div > ul .dropdown-menu li a:hover,
+.nav .dropdown-menu li a:hover {
+  background-color: #4e0242;
+  background-repeat: repeat-x;
+  background-image: -khtml-gradient(linear, left top, left bottom, from(#8A0474), to(#191919));
+  background-image: -moz-linear-gradient(top, #4e0242, #4e0242);
+  background-image: -ms-linear-gradient(top, #4e0242, #4e0242);
+  background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #4e0242), color-stop(100%, #4e0242));
+  background-image: -webkit-linear-gradient(top, #4e0242, #4e0242);
+  background-image: -o-linear-gradient(top, #4e0242, #4e0242);
+  background-image: linear-gradient(top, #4e0242, #4e0242);
+  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#4e0242', endColorstr='#4e0242', GradientType=0);
+  color: #ffffff;
+}
+
+a {
+  color: #8A0474;
+}
+
+a:hover {
+  color: #4e0242;
+}
Index: in/waeup.uniben/trunk/src/waeup/uniben/browser/static/custom_theme_1.css
===================================================================
--- /main/waeup.uniben/trunk/src/waeup/uniben/browser/static/custom_theme_1.css	(revision 8440)
+++ 	(revision )
@@ -1,72 +1,0 @@
-.topbar-inner, .topbar .fill {
-  background-color: #8A0474;
-  background-image: -moz-linear-gradient(center top , #4e0242, #8A0474);
-  background-image: -khtml-gradient(linear, left top, left bottom, from(#4e0242), to(#8A0474));
-  background-image: -moz-linear-gradient(top, #4e0242, #8A0474);
-  background-image: -ms-linear-gradient(top, #4e0242, #8A0474);
-  background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #4e0242), color-stop(100%, #8A0474));
-  background-image: -webkit-linear-gradient(top, #4e0242, #8A0474);
-  background-image: -o-linear-gradient(top, #4e0242, #8A0474);
-  background-image: linear-gradient(top, #4e0242, #8A0474);
-  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#4e0242', endColorstr='#8A0474', GradientType=0);
-}
-
-.topbar div > ul .active > a, .nav .active > a {
-  background-color: #8A0474;
-}
-
-.topbar h3 a:hover, .topbar .brand:hover, .topbar ul .active > a {
-  background-color: #8A0474;
-}
-
-.topbar div > ul a:hover, .nav a:hover {
-  background-color: #8A0474;
-}
-
-
-.topbar div > ul .menu-dropdown,
-.nav .menu-dropdown,
-.topbar div > ul .dropdown-menu,
-.nav .dropdown-menu {
-  background-color: #8A0474;
-}
-
-.topbar div > ul a.menu:hover,
-.nav a.menu:hover,
-.topbar div > ul li.open .menu,
-.nav li.open .menu,
-.topbar div > ul .dropdown-toggle:hover,
-.nav .dropdown-toggle:hover,
-.topbar div > ul .dropdown.open .dropdown-toggle,
-.nav .dropdown.open .dropdown-toggle {
-  background: #8A0474;
-}
-
-body {
-  background-color: #f3eff2;
-}
-
-.topbar div > ul .menu-dropdown li a:hover,
-.nav .menu-dropdown li a:hover,
-.topbar div > ul .dropdown-menu li a:hover,
-.nav .dropdown-menu li a:hover {
-  background-color: #4e0242;
-  background-repeat: repeat-x;
-  background-image: -khtml-gradient(linear, left top, left bottom, from(#8A0474), to(#191919));
-  background-image: -moz-linear-gradient(top, #4e0242, #4e0242);
-  background-image: -ms-linear-gradient(top, #4e0242, #4e0242);
-  background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #4e0242), color-stop(100%, #4e0242));
-  background-image: -webkit-linear-gradient(top, #4e0242, #4e0242);
-  background-image: -o-linear-gradient(top, #4e0242, #4e0242);
-  background-image: linear-gradient(top, #4e0242, #4e0242);
-  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#4e0242', endColorstr='#4e0242', GradientType=0);
-  color: #ffffff;
-}
-
-a {
-  color: #8A0474;
-}
-
-a:hover {
-  color: #4e0242;
-}
Index: /main/waeup.uniben/trunk/src/waeup/uniben/browser/tests.py
===================================================================
--- /main/waeup.uniben/trunk/src/waeup/uniben/browser/tests.py	(revision 8440)
+++ /main/waeup.uniben/trunk/src/waeup/uniben/browser/tests.py	(revision 8441)
@@ -52,6 +52,6 @@
         self.browser.addHeader('Authorization', 'Basic mgr:mgrpw')
         self.browser.open('http://localhost/app/configuration')
-        self.assertMatches('...Custom Theme 1...', self.browser.contents)
-        self.browser.getControl(name="form.skin").value = ['custom theme 1']
+        self.assertMatches('...Uniben Theme...', self.browser.contents)
+        self.browser.getControl(name="form.skin").value = ['custom theme']
         self.browser.getControl("Save").click()
         self.browser.open('http://localhost/app/configuration')
Index: /main/waeup.uniben/trunk/src/waeup/uniben/browser/theming.py
===================================================================
--- /main/waeup.uniben/trunk/src/waeup/uniben/browser/theming.py	(revision 8440)
+++ /main/waeup.uniben/trunk/src/waeup/uniben/browser/theming.py	(revision 8441)
@@ -18,16 +18,16 @@
 import grok
 from waeup.kofa.browser.interfaces import ITheme
-from waeup.uniben.browser.resources import custom_theme_1, favicon
+from waeup.uniben.browser.resources import custom_theme, favicon
 
 from waeup.uniben.interfaces import MessageFactory as _
 
-class CustomTheme1(grok.GlobalUtility):
+class CustomTheme(grok.GlobalUtility):
     """A custom theme based on the Kofa base theme.
     """
     grok.implements(ITheme)
-    grok.name('custom theme 1')
+    grok.name('custom theme')
 
-    description = _(u'Custom Theme 1')
+    description = _(u'Uniben Theme')
 
     def getResources(self):
-        return [custom_theme_1, favicon]
+        return [custom_theme, favicon]
Index: /main/waeup.uniben/trunk/src/waeup/uniben/etranzact/browser_templates/enterpin.pt
===================================================================
--- /main/waeup.uniben/trunk/src/waeup/uniben/etranzact/browser_templates/enterpin.pt	(revision 8440)
+++ /main/waeup.uniben/trunk/src/waeup/uniben/etranzact/browser_templates/enterpin.pt	(revision 8441)
@@ -1,4 +1,4 @@
 <form tal:attributes="action view/action"
-    method="POST" i18n:domain="waeup.uniben">
+    method="POST" i18n:domain="waeup.custom">
   <table class="form-table">
     <tbody>
Index: /main/waeup.uniben/trunk/src/waeup/uniben/ftesting.zcml
===================================================================
--- /main/waeup.uniben/trunk/src/waeup/uniben/ftesting.zcml	(revision 8440)
+++ /main/waeup.uniben/trunk/src/waeup/uniben/ftesting.zcml	(revision 8441)
@@ -2,5 +2,5 @@
    xmlns="http://namespaces.zope.org/zope"
    xmlns:kofa="http://namespaces.waeup.org/kofa"
-   i18n_domain="waeup.uniben"
+   i18n_domain="waeup.custom"
    package="waeup.uniben"
    >
Index: /main/waeup.uniben/trunk/src/waeup/uniben/interswitch/browser_templates/applicant_goto_interswitch.pt
===================================================================
--- /main/waeup.uniben/trunk/src/waeup/uniben/interswitch/browser_templates/applicant_goto_interswitch.pt	(revision 8440)
+++ /main/waeup.uniben/trunk/src/waeup/uniben/interswitch/browser_templates/applicant_goto_interswitch.pt	(revision 8441)
@@ -1,3 +1,3 @@
-<form i18n:domain="waeup.uniben"
+<form i18n:domain="waeup.custom"
   tal:attributes="action view/action" method="POST">
 
Index: /main/waeup.uniben/trunk/src/waeup/uniben/interswitch/browser_templates/student_goto_interswitch.pt
===================================================================
--- /main/waeup.uniben/trunk/src/waeup/uniben/interswitch/browser_templates/student_goto_interswitch.pt	(revision 8440)
+++ /main/waeup.uniben/trunk/src/waeup/uniben/interswitch/browser_templates/student_goto_interswitch.pt	(revision 8441)
@@ -1,3 +1,3 @@
-<form i18n:domain="waeup.uniben"
+<form i18n:domain="waeup.custom"
   tal:attributes="action view/action" method="POST">
 
Index: /main/waeup.uniben/trunk/src/waeup/uniben/permissions.py
===================================================================
--- /main/waeup.uniben/trunk/src/waeup/uniben/permissions.py	(revision 8440)
+++ /main/waeup.uniben/trunk/src/waeup/uniben/permissions.py	(revision 8441)
@@ -20,4 +20,8 @@
 
 class CRPUOfficer(grok.Role):
+    """ Permissions of Uniben CRPU members.
+
+    """
+
     grok.name('waeup.CRPUOfficer')
     grok.title(u'Uniben CRPU Officer')
Index: /main/waeup.uniben/trunk/src/waeup/uniben/students/browser_templates/payment_view.pt
===================================================================
--- /main/waeup.uniben/trunk/src/waeup/uniben/students/browser_templates/payment_view.pt	(revision 8440)
+++ /main/waeup.uniben/trunk/src/waeup/uniben/students/browser_templates/payment_view.pt	(revision 8441)
@@ -1,3 +1,3 @@
-<table class="form-table" i18n:domain="waeup.uniben"
+<table class="form-table" i18n:domain="waeup.custom"
   tal:define="files provider:files">
   <tbody>
Index: /main/waeup.uniben/trunk/src/waeup/uniben/students/interfaces.py
===================================================================
--- /main/waeup.uniben/trunk/src/waeup/uniben/students/interfaces.py	(revision 8440)
+++ /main/waeup.uniben/trunk/src/waeup/uniben/students/interfaces.py	(revision 8441)
@@ -337,5 +337,5 @@
         )
 
-    uniben_matric = schema.TextLine(
+    former_matric = schema.TextLine(
         title = _(u'If yes, matric number'),
         required = False,
Index: /main/waeup.uniben/trunk/src/waeup/uniben/students/utils.py
===================================================================
--- /main/waeup.uniben/trunk/src/waeup/uniben/students/utils.py	(revision 8440)
+++ /main/waeup.uniben/trunk/src/waeup/uniben/students/utils.py	(revision 8441)
@@ -130,4 +130,5 @@
         }
 
+    # Uniben separators
     SEPARATORS_DICT = {
         'form.fst_sit_fname': _(u'First Sitting Record'),
@@ -138,6 +139,7 @@
         'form.nysc_year': _(u'NYSC Information'),
         'form.employer': _(u'Employment History'),
-        'form.uniben_matric': _(u'Former Uniben Student'),
+        'form.former_matric': _(u'Former Uniben Student'),
         }
 
+    # Uniben prefix
     STUDENT_ID_PREFIX = u'B'
Index: /main/waeup.uniben/trunk/src/waeup/uniben/testing.py
===================================================================
--- /main/waeup.uniben/trunk/src/waeup/uniben/testing.py	(revision 8440)
+++ /main/waeup.uniben/trunk/src/waeup/uniben/testing.py	(revision 8441)
@@ -16,5 +16,5 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-"""Testing support for :mod:`waeup.uniben`.
+"""Testing support for custom package.
 """
 import os.path

Index: /main/waeup.uniben/trunk/src/waeup/uniben/interfaces.py
===================================================================
--- /main/waeup.uniben/trunk/src/waeup/uniben/interfaces.py	(revision 8440)
+++ /main/waeup.uniben/trunk/src/waeup/uniben/interfaces.py	(revision 8441)
@@ -23,5 +23,5 @@
 from waeup.uniben.utils.lgas import LGAS
 
-_ = MessageFactory = zope.i18nmessageid.MessageFactory('waeup.uniben')
+_ = MessageFactory = zope.i18nmessageid.MessageFactory('waeup.custom')
 
 high_qual = SimpleKofaVocabulary(
@@ -104,5 +104,5 @@
         )
 
     # Additional fees in waeup.uniben
 
     maint_fee = schema.Float(
@@ -104,5 +104,5 @@
         )
 
-    # Additional fees in waeup.uniben
+    # Additional fees in custom package
 
     maint_fee = schema.Float(